Change in simtrace2[master]: trace: increase watchdog for 500 to 2000 ms to provide more time hand...

This is merely a historical archive of years 2008-2021, before the migration to mailman3.

A maintained and still updated list archive can be found at https://lists.osmocom.org/hyperkitty/list/gerrit-log@lists.osmocom.org/.

Kévin Redon gerrit-no-reply at lists.osmocom.org
Tue Jul 3 16:45:26 UTC 2018


Kévin Redon has uploaded this change for review. ( https://gerrit.osmocom.org/9854


Change subject: trace: increase watchdog for 500 to 2000 ms to provide more time handling buffered data
......................................................................

trace: increase watchdog for 500 to 2000 ms to provide more time handling buffered data

Change-Id: Iacd85525f05e692b44183bd4c4585b9e70865cfe
---
M firmware/apps/trace/main.c
1 file changed, 3 insertions(+), 3 deletions(-)



  git pull ssh://gerrit.osmocom.org:29418/simtrace2 refs/changes/54/9854/1

diff --git a/firmware/apps/trace/main.c b/firmware/apps/trace/main.c
index e705a17..3dcbde1 100644
--- a/firmware/apps/trace/main.c
+++ b/firmware/apps/trace/main.c
@@ -40,7 +40,7 @@
 	void (*exit) (void);
 	/* main loop content for given configuration */
 	void (*run) (void);
-	/* Interrupt handler for USART1 */
+	/* Interrupt handler for USART0 */
 	void (*usart0_irq) (void);
 	/* Interrupt handler for USART1 */
 	void (*usart1_irq) (void);
@@ -148,9 +148,9 @@
 	led_init();
 	led_blink(LED_RED, BLINK_3O_5F);
 
 	/* Enable watchdog for 500ms, with no window */
 	WDT_Enable(WDT, WDT_MR_WDRSTEN | WDT_MR_WDDBGHLT | WDT_MR_WDIDLEHLT |
-		   (WDT_GetPeriod(500) << 16) | WDT_GetPeriod(500));
+		   (WDT_GetPeriod(2000) << 16) | WDT_GetPeriod(2000));
 
 	PIO_InitializeInterrupts(0);
 
@@ -148,9 +148,9 @@
 	led_blink(LED_RED, BLINK_3O_5F);
 
-	/* Enable watchdog for 500ms, with no window */
+	/* Enable watchdog for 2000 ms, with no window */
 	WDT_Enable(WDT, WDT_MR_WDRSTEN | WDT_MR_WDDBGHLT | WDT_MR_WDIDLEHLT |

-- 
To view, visit https://gerrit.osmocom.org/9854
To unsubscribe, or for help writing mail filters, visit https://gerrit.osmocom.org/settings

Gerrit-Project: simtrace2
Gerrit-Branch: master
Gerrit-MessageType: newchange
Gerrit-Change-Id: Iacd85525f05e692b44183bd4c4585b9e70865cfe
Gerrit-Change-Number: 9854
Gerrit-PatchSet: 1
Gerrit-Owner: Kévin Redon <kredon at sysmocom.de>
-------------- next part --------------
An HTML attachment was scrubbed...
URL: <http://lists.osmocom.org/pipermail/gerrit-log/attachments/20180703/06918343/attachment.htm>


More information about the gerrit-log mailing list